@@ -135,7 +135,7 @@ public abstract class AbstractPublicationService implements PublicationService {
 
     protected Publication loadInternally(Context ctx, int publicationId) throws PublicationException {
         Publication publication = STORAGE.getPublication(ctx, publicationId);
-        if (publication.getTarget() != null && publication.getTarget().getId().equals(getTarget().getId())) {
+        if (null != publication && publication.getTarget() != null && publication.getTarget().getId().equals(getTarget().getId())) {
             return publication;
         }
         return null;
